/* gltr_trim.p - Trim gltr_desc                                              */
/*                                                                           */
/* Copyright Boundless Technologies. All Rights Reserved.                    */
/* Supported by Boundless                                                    */
/*                                                                           */
/* Author:      Robert Archard       (Boundless)                             */
/*                                                                           */
/*V8:ConvertMode=FullGUIReport                                               */
/*                                                                           */
/*Parameters:                                                                */
/*                                                                           */
/* MM/DD/YY rev# ref    Description                                     Init */
/* -------- ---- ------ ----------------------------------------------- ---- */
/* 10/05/06 1.00        New maintenance program                         RDA  */

{mfdtitle.i "1.00"}

define variable entdate like gltr_ent_dt no-undo.
define variable entdate1 like gltr_ent_dt no-undo.
define variable effdate like gltr_eff_dt no-undo.
define variable effdate1 like gltr_eff_dt no-undo.
define variable rupdate like mfc_logical label "Update" initial no no-undo.

define variable cnt1 as integer label "Found" format ">>,>>>,>>9" no-undo.
define variable tlen as integer label "Trimmed" format ">,>>>,>>>,>>9" no-undo.
define variable vtable as character initial "gltr_hist" format "x(9)" label "Table" no-undo.

define buffer gltrhist for gltr_hist.

form
   "This maintenance program will trim excess space characters" colon 5
   "from the gltr_desc field.  MFG/Pro has a bug where is will" colon 5
   "add unecessary leading and trailing spaces." colon 5 skip(2)
   entdate   colon 25 label "Date Entered"
   entdate1  label {t001.i} colon 49
   effdate   colon 25 label "Date Effective"
   effdate1  label {t001.i} colon 49 skip(1)
   rupdate colon 25 skip(1)
   with frame a side-labels width 80.

{wbrp01.i}

repeat:
   if entdate = low_date then entdate = ?.
   if entdate1 = hi_date then entdate1 = ?.
   if effdate = low_date then effdate = ?.
   if effdate1 = hi_date then effdate1 = ?.

   if c-application-mode <> 'web':u then
      update
         entdate entdate1
         effdate effdate1
         rupdate
         with frame a.

   {wbrp06.i &command = update &fields = "entdate entdate1 effdate effdate1 rupdate" &frm = "a"}

   if (c-application-mode <> 'web':u) or
       (c-application-mode = 'web':u and
       (c-web-request begins 'data':u)) then do:

       bcdparm = "".
       {mfquoter.i entdate}
       {mfquoter.i entdate1}
       {mfquoter.i effdate}
       {mfquoter.i effdate1}
       {mfquoter.i rupdate}
   end.

   /* SELECT PRINTER */
   {mfselbpr.i "printer" 80}
   {mfphead.i}

   if entdate = ? then entdate = low_date.
   if entdate1 = ? then entdate1 = hi_date.
   if effdate = ? then effdate = low_date.
   if effdate1 = ? then effdate1 = hi_date.

   assign
     cnt1 = 0
     tlen = 0.

   for each gltr_hist
      fields(gltr_desc)
      where (gltr_ent_dt >= entdate and gltr_ent_dt <= entdate1)
        and (gltr_eff_dt >= effdate and gltr_eff_dt <= effdate1)
        and length(gltr_desc) <> length(trim(gltr_desc," "))
      no-lock:

      assign
         cnt1 = cnt1 + 1
         tlen = tlen + length(gltr_desc) - length(trim(gltr_desc," ")).

      if rupdate then do trans:
         find first gltrhist where rowid(gltrhist) = rowid(gltr_hist) exclusive-lock no-error.
         gltrhist.gltr_desc = trim(gltrhist.gltr_desc).
      end.

      {mfrpexit.i}
   end.

   display vtable cnt1 tlen with width 80 frame r1.

   {mfrtrail.i}
end.

{wbrp04.i &frame-spec = a}
